==> glog-1.00.tar.gz: glog-1.00/index.php <==
<?php
# Main page
#
# $Id: index.php,v 1.3.2.1 2004/04/15 09:35:58 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");

	html_begin("", false);
?>
<table class="menu" align="right" border="0" cellpadding="8" cellspacing="2">
<tr>
	<td nowrap = "nowrap">
<?php
	if (count($months) > 0) {
		print "<b></b><br />\n";
		foreach ($months as $month) {
			if (ereg("^([0-9]{4})-([0-9]{2})$", $month, $regs)) {
				$year = (int)$regs[1];
				$mon  = (int)$regs[2];
				print "<a href=\"" . BASEDIR . "month.php/{$month}\">{$months_bg[$mon]}, {$year}</a><br />\n";
			}
		}
	}

	$adventures = load_adventures();
	if (count($adventures) > 0) {
		print "<b></b><br />\n";
		foreach ($adventures as $link => $adventure) {
			print "<a href=\"" . BASEDIR . "adventure.php/{$link}\">{$adventure['title']}</a><br />\n";
 		}
	}
?>
<b>Blogs 'n stuff</b><br />
<a href="http://yovko.net/"> </a><br />
<a href="http://doganov.org/"> </a><br />
<a href="http://vasil.ludost.net/blog/"> </a><br />
<a href="http://extelligence.ringlet.net/techie-gone-nuts/"> </a><br />
<a href="http://extelligence.ringlet.net/roam/"> </a><br />
<a href="http://pocu.yovko.net/"> </a><br />
<a href="http://blog.doncho.net/"> </a><br />
<a href="http://turin.dnsalias.net/book"> </a><br />
<a href="http://www.ujournal.org/users/ylith/"> </a><br />
<a href="http://blog.peio.org/"> </a><br />
<a href="http://zdravko.openintegra.com/"> </a><br />
<a href="http://www.tonev.net/"> </a><br />
<a href="http://debian.fmi.uni-sofia.bg/~ogi/blog/"> </a><br />
<a href="http://ozlabs.com/~rusty/">Rusty Russell</a><br />
<a href="http://diary.codemonkey.org.uk/">Dave Jones</a><br />
<a href="http://primates.ximian.com/~rml/blog/">Robert Love</a><br />
<a href="http://maddox.xmission.com/">Maddox</a><br />
<a href="http://freak.unixsol.org/">Freak</a><br />
<b>Fun</b><br />
<a href="http://24gafa.unixsol.org/">24 </a><br />
<b>Syndicate</b><br />
<img src="<?=BASEDIR?>xml_rss.gif" border="0" width="36" height="14" alt="RDF" title="RSS 1.0 feed"/> <a href="<?=BASEDIR?>index.rdf.php">RSS 1.0</a><br />
<img src="<?=BASEDIR?>xml_rss.gif" border="0" width="36" height="14" alt="RDF" title="RSS 2.0 feed"/> <a href="<?=BASEDIR?>index.xml.php">RSS 2.0</a><br />
	</td>
</tr>
</table>

<?php
	$i = 0;
	if (count($days) > 0) {
		foreach ($days as $tmp => $date) {
			$text = implode('', file(get_filename($date)));
			print_day($date, $text);
			$i++;
			if ($i > 15)
				break;
		}
	} else {
		print "<h5>No entries found</h5><br />";
	}

	html_end();
?>

==> glog-2.00.tar.gz: glog-2.00/index.php <==
<?php
# Main page
#
# $Id: index.php,v 1.16 2004/11/01 12:22:56 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");

	html_begin("", false);
?>
<table class="menu" align="right" border="0" cellpadding="8" cellspacing="2">
<tr>
	<td nowrap = "nowrap">
<?php
	if (count($months) > 0) {
		print "<b></b><br />\n";
		foreach ($months as $month) {
			if (ereg("^([0-9]{4})-([0-9]{2})$", $month, $regs)) {
				$year = (int)$regs[1];
				$mon  = (int)$regs[2];
				print "<a href=\"" . BASEDIR . "month.php/{$month}\">{$months_txt[$mon]}, {$year}</a><br />\n";
			}
		}
	}

	$adventures = load_adventures();
	if (count($adventures) > 0) {
		print "<b></b><br />\n";
		foreach ($adventures as $link => $adventure) {
			print "<a href=\"" . BASEDIR . "adventure.php/{$link}\">{$adventure['title']}</a><br />\n";
 		}
	}
?>
<b>Free Software</b><br />
<a href="/programs/glog/">  </a><br />
<b>Blogs 'n stuff</b><br />
<a href="http://yovko.net/"> </a><br />
<a href="http://doganov.org/"> </a><br />
<a href="http://vasil.ludost.net/blog/"> </a><br />
<a href="http://extelligence.ringlet.net/techie-gone-nuts/"> </a><br />
<a href="http://extelligence.ringlet.net/roam/"> </a><br />
<a href="http://blog.doncho.net/"> </a><br />
<a href="http://turin.dnsalias.net/book"> </a><br />
<a href="http://ylith.peio.org/"> </a><br />
<a href="http://pocu.net/"> </a><br />
<a href="http://blog.peio.org/"> </a><br />
<a href="http://zdravko.openintegra.com/"> </a><br />
<a href="http://www.tonev.net/"> </a><br />
<a href="http://debian.fmi.uni-sofia.bg/~ogi/blog/"> </a><br />
<a href="http://yyovkov.net/"> </a><br />
<a href="http://www.karatebulgaria.com/alex/"> </a><br />
<a href="http://www.gerdjikovs.net/"> </a><br />
<a href="http://ozlabs.com/~rusty/">Rusty Russell</a><br />
<a href="http://diary.codemonkey.org.uk/">Dave Jones</a><br />
<a href="http://tech9.net/rml/log/">Robert Love</a><br />
<a href="http://maddox.xmission.com/">Maddox</a><br />
<b></b><br />
<a href="http://freak.unixsol.org/">Freak</a><br />
<a href="http://nesiprav.com/"></a><br />
<a href="http://koko.zadnik.org/"> </a><br />
<a href="http://fsa.kicks-ass.org/">FSA Planet</a><br />
<a href="http://www.nedyalkov.com/">Metalista</a><br />
<a href="http://www.iseca.org/">ISECA</a><br />
<a href="http://netsec.iseca.org/">NetSec @ FMI</a><br />
<b>Fun</b><br />
<a href="http://24gafa.unixsol.org/">24 </a><br />
<b>Syndicate</b><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="RDF" title="RSS 1.0 feed"/> <a href="<?=BASEDIR?>index.rdf.php">RSS 1.0</a><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="RDF" title="RSS 2.0 feed"/> <a href="<?=BASEDIR?>index.xml.php">RSS 2.0</a><br />
	</td>
</tr>
</table>

<?php
	$i = 0;
	if (count($days) > 0) {
		foreach ($days as $tmp => $date) {
			$text = implode('', file(get_filename($date)));
			print_day($date, $text);
			$i++;
			if ($i > FIRSTPAGE_ARTICLES)
				break;
		}
	} else {
		print "<h5>No entries found</h5><br />";
	}

	html_end();
?>
